.. mfw-template documentation master file, created by
   sphinx-quickstart on Mon Feb  4 18:42:20 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to mfw-template's documentation!
========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
